@@ -1,7 +1,7 @@
 from __init__ import Overwatch
 
 def main():
-    overwatch = Overwatch(battletag="Okush#11324", hero="dva", filter="miscellaneous")
+    overwatch = Overwatch(battletag="Okush#11324", hero="dva", filter="best")
  
 
     stats = overwatch()
